@@ -38,8 +38,7 @@ class DriverError(Exception):
                                             self.user_fault_string)
         self.operator_fault_string = kwargs.pop('operator_fault_string',
                                                 self.operator_fault_string)
-        super(DriverError, self).__init__(self.user_fault_string,
-                                          *args, **kwargs)
+        super().__init__(self.user_fault_string, *args, **kwargs)
 
 
 class NotImplementedError(Exception):
@@ -60,8 +59,7 @@ class NotImplementedError(Exception):
                                             self.user_fault_string)
         self.operator_fault_string = kwargs.pop('operator_fault_string',
                                                 self.operator_fault_string)
-        super(NotImplementedError, self).__init__(self.user_fault_string,
-                                                  *args, **kwargs)
+        super().__init__(self.user_fault_string, *args, **kwargs)
 
 
 class UnsupportedOptionError(Exception):
@@ -90,8 +88,7 @@ class UnsupportedOptionError(Exception):
                                             self.user_fault_string)
         self.operator_fault_string = kwargs.pop('operator_fault_string',
                                                 self.operator_fault_string)
-        super(UnsupportedOptionError, self).__init__(self.user_fault_string,
-                                                     *args, **kwargs)
+        super().__init__(self.user_fault_string, *args, **kwargs)
 
 
 class UpdateStatusError(Exception):
@@ -119,8 +116,7 @@ class UpdateStatusError(Exception):
         self.status_object_id = kwargs.pop('status_object_id', None)
         self.status_record = kwargs.pop('status_record', None)
 
-        super(UpdateStatusError, self).__init__(self.fault_string,
-                                                *args, **kwargs)
+        super().__init__(self.fault_string, *args, **kwargs)
 
 
 class UpdateStatisticsError(Exception):
@@ -149,8 +145,7 @@ class UpdateStatisticsError(Exception):
         self.stats_object_id = kwargs.pop('stats_object_id', None)
         self.stats_record = kwargs.pop('stats_record', None)
 
-        super(UpdateStatisticsError, self).__init__(self.fault_string,
-                                                    *args, **kwargs)
+        super().__init__(self.fault_string, *args, **kwargs)
 
 
 class DriverAgentNotFound(Exception):
@@ -165,8 +160,7 @@ class DriverAgentNotFound(Exception):
 
     def __init__(self, *args, **kwargs):
         self.fault_string = kwargs.pop('fault_string', self.fault_string)
-        super(DriverAgentNotFound, self).__init__(self.fault_string,
-                                                  *args, **kwargs)
+        super().__init__(self.fault_string, *args, **kwargs)
 
 
 class DriverAgentTimeout(Exception):
@@ -182,5 +176,30 @@ class DriverAgentTimeout(Exception):
 
     def __init__(self, *args, **kwargs):
         self.fault_string = kwargs.pop('fault_string', self.fault_string)
-        super(DriverAgentTimeout, self).__init__(self.fault_string,
-                                                 *args, **kwargs)
+        super().__init__(self.fault_string, *args, **kwargs)
+
+
+class NotFound(Exception):
+    """Exception raised when the driver cannot find a resource.
+
+    This exception includes two strings: The user fault string and the
+    optional operator fault string. The user fault string,
+    "user_fault_string", will be provided to the API requester. The operator
+    fault string, "operator_fault_string",  will be logged in the Octavia API
+    log file for the operator to use when debugging.
+
+    :param user_fault_string: String provided to the API requester.
+    :type user_fault_string: string
+    :param operator_fault_string: Optional string logged by the Octavia API
+      for the operator to use when debugging.
+    :type operator_fault_string: string
+    """
+    user_fault_string = _("The provider driver could not find a resource.")
+    operator_fault_string = _("The provider driver could not find a resource.")
+
+    def __init__(self, *args, **kwargs):
+        self.user_fault_string = kwargs.pop('user_fault_string',
+                                            self.user_fault_string)
+        self.operator_fault_string = kwargs.pop('operator_fault_string',
+                                                self.operator_fault_string)
+        super().__init__(self.user_fault_string, *args, **kwargs)
