@@ -163,6 +163,7 @@ AMPHORA_ALLOCATED = 'ALLOCATED'
 AMPHORA_BOOTING = 'BOOTING'
 # Amphora is ready to be allocated to a load balancer
 AMPHORA_READY = 'READY'
+AMPHORA_FAILOVER_STOPPED = 'FAILOVER_STOPPED'
 ACTIVE = 'ACTIVE'
 PENDING_DELETE = 'PENDING_DELETE'
 PENDING_UPDATE = 'PENDING_UPDATE'
@@ -170,6 +171,7 @@ PENDING_CREATE = 'PENDING_CREATE'
 DELETED = 'DELETED'
 SUPPORTED_PROVISIONING_STATUSES = (ACTIVE, AMPHORA_ALLOCATED,
                                    AMPHORA_BOOTING, AMPHORA_READY,
+                                   AMPHORA_FAILOVER_STOPPED,
                                    PENDING_DELETE, PENDING_CREATE,
                                    PENDING_UPDATE, DELETED, ERROR)
 
@@ -232,6 +234,9 @@ EXPECTED_CODES = 'expected_codes'
 FALL_THRESHOLD = 'fall_threshold'
 HEALTHMONITOR = 'healthmonitor'
 HEALTHMONITOR_ID = 'healthmonitor_id'
+HSTS_MAX_AGE = 'hsts_max_age'
+HSTS_INCLUDE_SUBDOMAINS = 'hsts_include_subdomains'
+HSTS_PRELOAD = 'hsts_preload'
 HTTP_METHOD = 'http_method'
 HTTP_VERSION = 'http_version'
 INSERT_HEADERS = 'insert_headers'
